@@ -1,6 +1,7 @@
 """Cmeel build."""
 import logging
 import os
+import re
 import sys
 import warnings
 from pathlib import Path
@@ -18,6 +19,7 @@ from . import __version__
 from .config import cmeel_config
 from .consts import CMEEL_PREFIX, SITELIB
 
+LOG = logging.getLogger("cmeel")
 EXECUTABLE = """#!python
 from cmeel.run import cmeel_run
 cmeel_run()
@@ -69,7 +71,19 @@ def deprecate_build_system(pyproject, key, default):
 
 def build_wheel(wheel_directory, config_settings=None, metadata_directory=None):
     """Main entry point for PEP 517."""
-    logging.info("CMake Wheel")
+    logging.basicConfig(level=cmeel_config.log_level.upper())
+    LOG.info("CMake Wheel")
+
+    if LOG.getEffectiveLevel() <= logging.DEBUG:
+        try:
+            import pip  # noqa: F401
+
+            LOG.debug("pip freeze:")
+            deps = check_output([sys.executable, "-m", "pip", "freeze"], text=True)
+            for dep in deps.strip().split("\n"):
+                LOG.debug(f"  {dep}")
+        except ModuleNotFoundError:
+            LOG.debug("pip is not available")
 
     TEMP = cmeel_config.temp_dir
     BUILD = TEMP / "bld"
@@ -82,7 +96,7 @@ def build_wheel(wheel_directory, config_settings=None, metadata_directory=None):
         plat = os.environ["_PYTHON_HOST_PLATFORM"].replace("-", "_").replace(".", "_")
         TAG = "-".join(TAG.split("-")[:-1] + [plat])
 
-    logging.info("load conf from pyproject.toml")
+    LOG.info("load conf from pyproject.toml")
     with open("pyproject.toml", "rb") as f:
         pyproject = tomli.load(f)
         CONF = pyproject["project"]
@@ -104,12 +118,12 @@ def build_wheel(wheel_directory, config_settings=None, metadata_directory=None):
         CHECK_RELOCATABLE = deprecate_build_system(pyproject, "check-relocatable", True)
     DISTRIBUTION = CONF["name"].replace("-", "_")
 
-    logging.info("build wheel")
+    LOG.info("build wheel")
 
     # Patch
 
     if Path("cmeel.patch").exists():
-        logging.info("patching")
+        LOG.info("patching")
         cmd = ["patch", "-p0", "-s", "-N", "-i", "cmeel.patch"]
         ret = run(cmd, capture_output=True, text=True)
         if ret.returncode != 0:
@@ -123,7 +137,7 @@ def build_wheel(wheel_directory, config_settings=None, metadata_directory=None):
                     output=ret.stdout,
                     stderr=ret.stderr + f"\nwrong line: {line}\n",
                 )
-            logging.info("this patch was already applied")
+            LOG.info("this patch was already applied")
 
     # Set env
 
@@ -136,32 +150,41 @@ def build_wheel(wheel_directory, config_settings=None, metadata_directory=None):
 
     # Configure
 
-    logging.info("configure")
+    LOG.info("configure")
     configure_env = cmeel_config.get_configure_env()
     configure_args = cmeel_config.get_configure_args(
         CONF, INSTALL, CONFIGURE_ARGS, configure_env, RUN_TESTS
     )
-    check_call(["cmake", "-S", SOURCE, "-B", BUILD] + configure_args, env=configure_env)
+    configure_cmd = ["cmake", "-S", SOURCE, "-B", str(BUILD)] + configure_args
+    LOG.debug(f"configure environment: {configure_env}")
+    LOG.debug(f"configure command: {configure_cmd}")
+    check_call(configure_cmd, env=configure_env)
 
-    logging.info("build")
-    check_call(["cmake", "--build", BUILD, f"-j{cmeel_config.jobs}"])
+    LOG.info("build")
+    build_cmd = ["cmake", "--build", str(BUILD), f"-j{cmeel_config.jobs}"]
+    LOG.debug(f"build command: {build_cmd}")
+    check_call(build_cmd)
 
     def run_tests():
-        logging.info("test")
+        LOG.info("test")
         test_env = cmeel_config.get_test_env()
         test_cmd = [i.replace("BUILD_DIR", str(BUILD)) for i in TEST_CMD]
-        check_call(test_cmd, env=test_env, shell=True)
+        LOG.debug(f"test environment: {test_env}")
+        LOG.debug(f"test command: {test_cmd}")
+        check_call(test_cmd, env=test_env)
 
     if RUN_TESTS and not RUN_TESTS_AFTER_INSTALL:
         run_tests()
 
-    logging.info("install")
-    check_call(["cmake", "--build", BUILD, "-t", "install"])
+    LOG.info("install")
+    install_cmd = ["cmake", "--build", str(BUILD), "-t", "install"]
+    LOG.debug(f"install command: {install_cmd}")
+    check_call(install_cmd)
 
     if RUN_TESTS and RUN_TESTS_AFTER_INSTALL:
         run_tests()
 
-    logging.info("fix relocatablization")
+    LOG.info("fix relocatablization")
     # Replace absolute install path in generated .cmake files, if any.
     for f in INSTALL.rglob("*.cmake"):
         ff = INSTALL / f"{f.stem}.fix"
@@ -170,12 +193,12 @@ def build_wheel(wheel_directory, config_settings=None, metadata_directory=None):
         f.unlink()
         ff.rename(f)
 
-    logging.info("create dist-info")
+    LOG.info("create dist-info")
 
     dist_info = PREFIX / f"{DISTRIBUTION}-{CONF['version']}.dist-info"
     dist_info.mkdir()
 
-    logging.info("create dist-info / METADATA")
+    LOG.info("create dist-info / METADATA")
 
     metadata = [
         "Metadata-Version: 2.1",
@@ -245,11 +268,11 @@ def build_wheel(wheel_directory, config_settings=None, metadata_directory=None):
     with (dist_info / "METADATA").open("w") as f:
         f.write("\n".join(metadata))
 
-    logging.info("create dist-info / top level")
+    LOG.info("create dist-info / top level")
     with (dist_info / "top_level.txt").open("w") as f:
         f.write("")
 
-    logging.info("create dist-info / WHEEL")
+    LOG.info("create dist-info / WHEEL")
     with (dist_info / "WHEEL").open("w") as f:
         f.write(
             "\n".join(
@@ -264,7 +287,7 @@ def build_wheel(wheel_directory, config_settings=None, metadata_directory=None):
 
     BIN = INSTALL / "bin"
     if BIN.is_dir():
-        logging.info("adding executables")
+        LOG.info("adding executables")
         scripts = PREFIX / f"{DISTRIBUTION}-{CONF['version']}.data" / "scripts"
         scripts.mkdir(parents=True)
         for fn in BIN.glob("*"):
@@ -274,7 +297,7 @@ def build_wheel(wheel_directory, config_settings=None, metadata_directory=None):
             executable.chmod(0o755)
 
     if CHECK_RELOCATABLE:
-        logging.info("check generated cmake files")
+        LOG.info("check generated cmake files")
         WRONG_DIRS = [
             "/tmp/pip-build-env",
             "/tmp/pip-req-build",
@@ -304,8 +327,8 @@ def build_wheel(wheel_directory, config_settings=None, metadata_directory=None):
                         f"{fc} references temporary paths:\n" + "\n".join(display)
                     )
 
-    logging.info("wheel pack")
-    name = check_output(
+    LOG.info("wheel pack")
+    pack = check_output(
         [
             sys.executable,
             "-m",
@@ -315,10 +338,12 @@ def build_wheel(wheel_directory, config_settings=None, metadata_directory=None):
             str(BUILD_NUMBER),
             "-d",
             wheel_directory,
-            PREFIX,
+            str(PREFIX),
         ]
     ).decode()
-    name = name.split("/")[-1][:-6]
+    LOG.debug("wheel pack output: {pack}")
+    name = Path(re.search("Repacking wheel as (.*\\.whl)\\.\\.\\.", pack).group(1)).name
+    LOG.debug(f"returning '{name}'")
 
-    logging.info("done")
+    LOG.info("done")
     return name
